@@ -1,9 +1,12 @@
 package Koha::Contrib::Tamil;
 {
-  $Koha::Contrib::Tamil::VERSION = '0.010';
+  $Koha::Contrib::Tamil::VERSION = '0.011';
 }
 # ABSTRACT: Various scripts to manage Koha instances
 
+use warnings;
+use strict;
+
 1;
 
 
@@ -18,7 +21,7 @@ Koha::Contrib::Tamil - Various scripts to manage Koha instances
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 DESCRIPTION
 
