@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::Authority::FromBiblioTask;
 {
-  $Koha::Contrib::Tamil::Authority::FromBiblioTask::VERSION = '0.010';
+  $Koha::Contrib::Tamil::Authority::FromBiblioTask::VERSION = '0.011';
 }
 # ABSTRACT: Task extracting authorities from biblio records
 
@@ -91,16 +91,18 @@ sub process {
         return 1;
     }
 
-    print "    bibios count:   ", $self->count, "\n";
+    print __x("  bibios count:   {count}",
+              count => $self->count), "\n";
 
     my $tmp_file = $self->tmp_file;
     my $output   = $self->output;
 
-    print <<EOS;
-Sort and de-duplicate
-    source:         $tmp_file
-    target:         $output
-EOS
+    print __x(
+              "Sort and de-duplicate\n" .
+              "  source:         {tmp_file}\n" .
+              "  target:         {output}\n",
+              tmp_file => $tmp_file,
+              output => $output );
     system( "sort -f $tmp_file | uniq -i >$output" );
 
     return 0;
@@ -122,7 +124,7 @@ Koha::Contrib::Tamil::Authority::FromBiblioTask - Task extracting authorities fr
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 AUTHOR
 
