@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::FileProcess;
 {
-  $Koha::Contrib::Tamil::FileProcess::VERSION = '0.010';
+  $Koha::Contrib::Tamil::FileProcess::VERSION = '0.011';
 }
 #ABSTRACT: FileProcess - Base class for file processing
 
@@ -54,6 +54,8 @@ sub run_blocking {
 sub run_task {
     my $self = shift;
 
+    $self->start_process();
+
     if ( $self->verbose ) {
         my $watcher = Koha::Contrib::Tamil::EchoWatcher->new(
             delay => 1, action => $self );
@@ -65,6 +67,7 @@ sub run_task {
     my $idle = AnyEvent->idle(
         cb => sub {
             unless ( $self->process() ) {
+                $self->end_process();
                 $self->watcher->stop() if $self->watcher;
                 $end_run->send;
             }
@@ -74,10 +77,7 @@ sub run_task {
 }
 
 
-sub process {
-    my $self = shift;
-    $self->count( $self->count + 1 );
-}
+sub start_process { }
 
 
 sub start_message {
@@ -85,11 +85,21 @@ sub start_message {
 }
 
 
+sub process {
+    my $self = shift;
+    $self->count( $self->count + 1 );
+}
+
+
 sub process_message {
     my $self = shift;
     print sprintf("  %#6d", $self->count), "\n";    
 }
 
+
+sub end_process { return 0; }
+
+
 sub end_message {
     my $self = shift; 
     print __xn("One record processed",
@@ -116,7 +126,7 @@ Koha::Contrib::Tamil::FileProcess - FileProcess - Base class for file processing
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 AUTHOR
 
